##  User Details
To view information for a specific user, on the Users page, select a user by clicking their email address. On the user details page, you can:
  * View user details: This includes the user's email address, name, status, role, and last login time.
  * Deactivate a user: To deactivate a user, click Archive next to Status. You can't delete users. You can only archive them.
  * Change the user's role: If SSO isn't enabled or you're managing roles within SAP LeanIX with SSO, you can change a user’s role on the user details page. Select a different role from the Roles list and click Save. The new role takes effect upon the user's next sign-in.
  * View user's fact sheet subscriptions: On the User Subscriptions tab, you can view all fact sheets a user is subscribed to, along with their subscription type and role for each fact sheet.


![User Details Page](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27445f337a4410148f3ce5d5df041d77_LowRes.png)
User Details Page
YesNo
Send
